{% load i18n %}
{% load humanize %}
{% load price_formats %}
{% load static %}

            <table id="contract" class="table">
                <tr>
                    <th>{% trans "Price before expenses" %}</th>
                    <td>{{tracking.value|custom_number_format:2}} ISK</td>
                </tr>
                <tr>
                    <th>{% trans "Program taxes" %}</th>
                  <td>{{tracking.taxes|custom_number_format:2}} ISK</td>
                </tr>
                <tr>
                    <th>{% trans "Hauling cost" %}</th>
                    <td>{{tracking.hauling_cost|custom_number_format:2}} ISK</td>
                </tr>
                <tr>
                    <th>{% trans "Donation amount" %}</th>
                    <td>{{tracking.donation|custom_number_format:2}} ISK <i></i></td>
                </tr>
                <tr>
                    <th style="border-top:2px dotted black;">Net price</th>
                    {% if tracking.net_price >= 0 %}
                        <td style="border-top:2px dotted black;">{{tracking.net_price|custom_number_format:2 }} ISK</td>
                    {% else %}
                        <td style="border-top:2px dotted black;">0 ISK <i><s>{{tracking.net_price|custom_number_format:2 }} ISK</s></i><td>
                    {% endif %}
                </tr>

            </table>
