{% load static %}
{% load i18n %}
{% load navactive %}

        <li class="nav-item">
            <a href="{% url 'buybackprogram:setup' %}" class="nav-link py-0">
                <span class="btn btn-info">{% trans "1. Setup Manager" %}</span>
            </a>
        </li>
        <li class="nav-item">
            <a href="{% url 'buybackprogram:location_add' %}" class="nav-link py-0">
                <span class="btn btn-info">{% trans "2. Add/edit location" %}</span>
            </a>
        </li>
        <li class="nav-item">
            <a href="{% url 'buybackprogram:program_add' %}" class="nav-link py-0">
                <span class="btn btn-info">{% trans "3. Create Program" %}</span>
            </a>
        </li>
