{% load i18n %}
{% load humanize %}
{% load price_formats %}
{% load static %}
<div id="tab-contract" class="tab-pane fade card card-default border-0" role="tabpanel" aria-labelledby="tab-outstanding">
    <table class="table table-striped table-condensed">
            <thead>
                <tr>
                    <th>{% trans "Name" %}</th>
                    <th>{% trans "Quantity" %}</th>
                    <th>{% trans "Note" %}</th>
                </tr>
            </thead>
            <tbody>
                {% for item in contract_items %}
                        <tr>
                            <td><img class="item-icon" src="https://image.eveonline.com/Type/{{item.eve_type.id}}_64.png" />{{item.eve_type.name}}</td>
                            <td>{{item.quantity|intcomma}}</td>
                            <td>
                                {% for note in item.notes %}
                                    <i style="color: {{note.color}};" class="fas {{note.icon}}" title="{{note.message}}"></i>
                                {% endfor %}
                            </td>
                        </tr>
                {% endfor %}
            </tbody>
        </table>
</div>
