{% extends 'buybackprogram/base.html' %}
{% load i18n %}
{% load humanize %}
{% load price_formats %}
{% load static %}
{% block details %}

<div class="panel-body" style="min-height: 100px;">
    <div class="row row-cols-1 row-cols-md-2 g-4">
        <div class="col">
            <div class="card">
                <div class="card-header">{% trans "Contract Information" %}</div>
                <div class="card-body">
                    {% include "buybackprogram/partials/details/contract-info.html" %}
                </div>
            </div>
        </div>
        <div class="col">
            <div class="card">
                <div class="card-header">{% trans "Contract Notes" %}
                <div class="card-body">
                    {% include "buybackprogram/partials/details/warning.html" %}
                </div>
                </div>
            </div>
        </div>
    </div>

    <div class="card" style="margin-top:10px">
        <div class="card-header">{% trans "Accepted Location(s)" %}</div>
        <div class="card-body">
            {% include "buybackprogram/partials/details/accepted-locations.html" %}
        </div>
    </div>

    <div class="card" style="margin-top:10px">
        <div class="card-header">{% trans "Invoice" %}</div>
        <div class="card-body">
            {% include "buybackprogram/partials/details/invoice.html" %}
        </div>
    </div>

    <div class="card" style="margin-top:10px">
        <div class="card-header">{% trans "Contract items" %}</div>
        <div class="card-body">
            <!-- Nav tabs -->
            {% include "buybackprogram/partials/details/tabs/tabs-navigation.html" %}

            <div class="tab-content" id="nav-tabContent">
                {% include "buybackprogram/partials/details/tabs/contract-items.html" %}
                {% include "buybackprogram/partials/details/tabs/original-items.html" %}
            </div>
        </div>
    </div>

    <div>
        <a class="btn btn-warning btn-sm" href="{% url 'buybackprogram:my_stats' %}">
                                <i class="fas fa-arrow-left"></i> {% trans "Back to my stats" %}
        </a>
    </div>
</div>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% if NIGHT_MODE %}
        <link rel="stylesheet" type="text/css" href="{% static 'buybackprogram/css/style_dark.css' %}">
        {% else %}
        <link rel="stylesheet" type="text/css" href="{% static 'buybackprogram/css/style_light.css' %}">
    {% endif %}
{% endblock %}

{% block extra_script %}
{% endblock %}
