# Generated by Django 4.0.10 on 2023-12-31 13:21

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("buybackprogram", "0013_program_discord_show_item_list"),
    ]

    operations = [
        migrations.AddField(
            model_name="program",
            name="price_type",
            field=models.CharField(
                choices=[("Buy", "Buy"), ("Sell", "Sell"), ("Split", "Split")],
                default="Buy",
                help_text="What prices should we use as the source for prices. Default: Buy",
                max_length=7,
            ),
        ),
    ]
