{% load humanize %}
{% load i18n %}
{% load price_formats %}
        <table id="contract" class="table table-striped table-hover no-footer w-100">
            <tr>
                <th>{% trans "Contract type:" %}</th>
                <td colspan="2">{% trans "Item Exchange" %}</td>

            </tr>
            <tr>
                <th>{% trans "Availability:" %}</th>
                {% if program.is_corporation %}
                    <td data-type="copy_value">{{program.owner.corporation}}</td>
                    <td><button data-type="copy"><i class="fa-solid fa-copy"></i></button></td>
                {% else %}
                    <td data-type="copy_value">{{program.owner.character.character}}</td>
                    <td><button data-type="copy"><i class="fa-solid fa-copy"></i></button></td>
                {% endif %}
            </tr>
            <tr>
                <th>{% trans "I will receive:" %}</th>
                {% if contract_price_data.contract_net_total >= 0%}
                    <td data-type="copy_value">{{ contract_price_data.contract_net_total|custom_number_format:2 }}</td>
                    <td><button data-type="copy"><i class="fa-solid fa-copy"></i></button></td>
                {% else %}
                    <td>0 ISK <i><s>{{ contract_price_data.contract_net_total|custom_number_format:2 }} ISK</s></i><td>
                {% endif %}


            </tr>
            <tr>
                <th>{% trans "Expiration:" %}</th>
                <td colspan="2">{{program.expiration}}</td>
            </tr>
            <tr>
                <th>{% trans "Description:" %}</th>
                <td data-type="copy_value">{{tracking_number}}</td>
                <td><button data-type="copy"><i class="fas fa-copy"></i></button></td>
            </tr>
        </table>
