{% extends 'buybackprogram/page.html' %}
{% load i18n %}
{% load humanize %}
{% load bootstrap %}

{% block body %}
<div class="card">
  <h5 class="card-header">{% trans "Create New Program" %}</h5>
  <div class="card-body">
      <form class="form" action="{{ url }}" method="POST">
      {% csrf_token %}
      {{ form|bootstrap }}
      <button type="submit" class="btn btn-primary">{% trans "Create program" %}</button>
    </form>
  </div>
</div>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% include "buybackprogram/bundles/buybackprogram-css-light.html" %}
{% endblock %}

{% block extra_script %}
{% endblock %}
