{% extends 'buybackprogram/page.html' %}
{% load i18n %}
{% load humanize %}
{% load bootstrap %}
{% load static %}

{% block body %}
<div class="card text-center">
  <div class="card-header">
    {% trans "Buyback user settings" %}
  </div>
  <div class="card-body">
    <form class="form" action="{% url 'buybackprogram:user_settings_edit' %}" method="POST">
      {% csrf_token %}
      {{ form|bootstrap }}
      <button type="submit" class="btn btn-primary">{% trans "Update Settings" %}</button>
    </form>
  </div>
</div>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
