{% extends 'buybackprogram/page.html' %}
{% load i18n %}
{% load humanize %}
{% load price_formats %}

{% block body %}

    <div class="card">
        <div class="card-header">{% trans "Summary" %}</div>
        <div class="card-body">
            {% include "buybackprogram/partials/stats/summary.html" %}
        </div>
    </div>

    {% if values.untracked_count > 0 %}
        <div class="card" style="margin-top:10px">
            <div class="card-header">{% trans "Notes" %}</div>
            <div class="card-body">
                {% include "buybackprogram/partials/stats/warning.html" %}
            </div>
        </div>
    {% endif %}

    <div class="card" style="margin-top:10px">
        <div class="card-header">{% trans "Contracts" %}</div>
        <div class="card-body">
            <!-- Nav tabs -->
            {% include "buybackprogram/partials/stats/tabs/tabs-navigation.html" %}

            <div class="tab-content" id="nav-tabContent">

                {% include "buybackprogram/partials/stats/tabs/outstanding.html" %}
                {% include "buybackprogram/partials/stats/tabs/finished.html" %}
                {% include "buybackprogram/partials/stats/tabs/untracked.html" %}

            </div>
        </div>
    </div>



{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% include "buybackprogram/bundles/buybackprogram-css-light.html" %}
{% endblock %}

{% block extra_script %}
{% endblock %}
