<div class="card bg-warning">
        <div class="card-header"><i class="fas fa-exclamation-triangle"></i> Warning: Untracked Contracts"</div>
        <div class="card-body">
        You have {{values.untracked_count}} outstanding contracts that start with the buyback prefill text but do not match any tracking objects in your programs! These contracts are possibly scam contracts trying to identify as valid buyback contracts.
        </div>
</div>
