{% load i18n %}
{% load humanize %}
{% load price_formats %}
<table class="table table-striped table-hover no-footer w-100" id="dashboard-recent-fatlinks">
    <tbody>
        <tr>
            <th>{% trans "Outstanding count:" %}</th>
            <td>{{values.outstanding_count}}</td>
            <th>{% trans "Outstanding value:" %}</th>
            <td>{{values.outstanding|custom_number_format:2|price}}</td>
        </tr>
        <tr>
            <th>{% trans "Total bought count:" %}</th>
            <td>{{values.finished_count}}</td>
            <th>{% trans "Total bought:" %}</th>
            <td>{{values.finished|custom_number_format:2|price}}</td>
        </tr>
        {% if BUYBACKPROGRAM_TRACK_PREFILL_CONTRACTS %}
            <tr>
                <th>{% trans "Untracked count:" %}</th>
                <td>{{values.untracked_count}}</td>
                </tr>
        {% endif %}
    </tbody>

    <tfoot>
    </tfoot>
</table>
