# Generated by Django 4.2.11 on 2024-05-11 11:42

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("buybackprogram", "0014_program_price_type"),
    ]

    operations = [
        migrations.CreateModel(
            name="Faq",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("header", models.CharField(max_length=1024)),
                ("body", models.TextField()),
            ],
        ),
        migrations.AddField(
            model_name="contractnotification",
            name="header",
            field=models.CharField(blank=True, max_length=1024, null=True),
        ),
        migrations.AddField(
            model_name="tracking",
            name="additional_notes",
            field=models.TextField(blank=True, null=True),
        ),
    ]
